@@ -1,12 +1,13 @@
 conda install --yes pip
 pip install wget
 python -m wget https://raw.githubusercontent.com/mjirik/lisa/master/requirements_pip.txt -o requirements_pip.txt
-python -m wget https://raw.githubusercontent.com/mjirik/lisa/master/requirements_conda.txt -o requirements_conda.txt
-python -m wget https://raw.githubusercontent.com/mjirik/lisa/master/requirements_conda_root.txt -o requirements_conda_root.txt
+#python -m wget https://raw.githubusercontent.com/mjirik/lisa/master/requirements_conda.txt -o requirements_conda.txt
+#python -m wget https://raw.githubusercontent.com/mjirik/lisa/master/requirements_conda_root.txt -o requirements_conda_root.txt
 
 
-conda install --yes --file requirements_conda_root.txt
-conda install --yes -c SimpleITK -c menpo -c mjirik  --file requirements_conda.txt
+#conda install --yes --file requirements_conda_root.txt
+#conda install --yes -c SimpleITK -c menpo -c mjirik  --file requirements_conda.txt
+conda install --yes -c SimpleITK -c menpo -c mjirik  lisa
 # mahotas on luispedro is only for linux
 # conda install --yes -c SimpleITK -c luispedro --file requirements_conda.txt
 
@@ -17,7 +18,7 @@ easy_install -U --user mahotas
 pip install -U --no-deps -r requirements_pip.txt --user
 
 # linux specific
-pip install scikit-fmm
+pip install scikit-fmm nomkl
 
 mkdir projects
 
