@@ -1,8 +1,10 @@
 __all__ = ['organ_segmentation']
 #, 'qmisc', 'misc', 'experiments',
            #'support_structure_segmentation']
+__version__ = "1.9.2"
+
 import organ_segmentation
-from organ_segmentation import main
+from main import lisa_main
 # import qmisc
 # import misc
 # import experiments
