@@ -12,6 +12,7 @@ import numpy as np
 import subprocess
 
 import datetime
+import functools
 
 from io3d import datareader
 # import segmentation
@@ -52,7 +53,7 @@ def find_logo():
     if os.path.exists(logopath):
         return logopath
     # lisa runtime directory
-    logopath = os.path.expanduser("~/lisa_data/LISA256.png")
+    logopath = os.path.expanduser("~/lisa_data/.lisa/LISA256.png")
     if not os.path.exists(logopath):
         try:
             wget.download(
@@ -76,6 +77,7 @@ class OrganSegmentationWindow(QMainWindow):
 
         QMainWindow.__init__(self)
         self._initUI()
+        self._initMenu()
 
         if oseg is not None:
             if oseg.data3d is not None:
@@ -86,21 +88,88 @@ class OrganSegmentationWindow(QMainWindow):
 
 
     def _initMenu(self):
+        menubar = self.menuBar()
+
+        ###### FILE MENU ######
+        fileMenu = menubar.addMenu('&File')
+        loadSubmenu = fileMenu.addMenu('&Load')
+        # load dir
+        loadDirAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Directory', self)
+        loadDirAction.setStatusTip('Load data from directory (DICOM, jpg, png...)')
+        loadDirAction.triggered.connect(self.loadDataDir)
+        loadSubmenu.addAction(loadDirAction)
+        # load file
+        loadFileAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&File', self)
+        loadFileAction.setStatusTip('Load data from file (pkl, 3D Dicom, tiff...)')
+        loadFileAction.triggered.connect(self.loadDataFile)
+        loadSubmenu.addAction(loadFileAction) 
+        
+        saveSubmenu = fileMenu.addMenu('&Save')
+        # save file
+        saveFileAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&File', self)
+        saveFileAction.setStatusTip('Save data with segmentation')
+        saveFileAction.triggered.connect(self.saveOut)
+        saveSubmenu.addAction(saveFileAction)   
+        # save dicom
+        saveDicomAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&DICOM', self)
+        saveDicomAction.setStatusTip('Save DICOM data')
+        saveDicomAction.triggered.connect(self.btnSaveOutDcm)
+        saveSubmenu.addAction(saveDicomAction)
+        # save dicom overlay
+        saveDicomOverlayAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&DICOM overlay', self)
+        saveDicomOverlayAction.setStatusTip('Save overlay DICOM data')
+        saveDicomOverlayAction.triggered.connect(self.btnSaveOutDcmOverlay)
+        saveSubmenu.addAction(saveDicomOverlayAction)     
+        # save PV tree
+        savePVAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&PV tree', self)
+        savePVAction.setStatusTip('Save Portal Vein 1D model')
+        savePVAction.triggered.connect(self.btnSavePortalVeinTree)
+        saveSubmenu.addAction(savePVAction)     
+        # save HV tree
+        saveHVAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&HV tree', self)
+        saveHVAction.setStatusTip('Save Hepatic Veins 1D model')
+        saveHVAction.triggered.connect(self.btnSaveHepaticVeinsTree)
+        saveSubmenu.addAction(saveHVAction)     
+
+        separator = fileMenu.addAction("")
+        separator.setSeparator(True)
+
+        autoSeedsAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Automatic liver seeds', self)
+        autoSeedsAction.setStatusTip('Automatic liver seeds')
+        autoSeedsAction.triggered.connect(self.btnAutomaticLiverSeeds)
+        fileMenu.addAction(autoSeedsAction)
+
+        autoSegAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Automatic segmentation', self)
+        autoSegAction.setStatusTip('Automatic segmentation')
+        autoSegAction.triggered.connect(self.btnAutoSeg)
+        fileMenu.addAction(autoSegAction)
+
+        cropAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Crop', self)
+        cropAction.setStatusTip('')
+        cropAction.triggered.connect(self.cropDcm)
+        fileMenu.addAction(cropAction)
+
+        maskAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Mask region', self)
+        maskAction.setStatusTip('')
+        maskAction.triggered.connect(self.maskRegion)
+        fileMenu.addAction(maskAction)
+
+        view3DAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&View 3D', self)
+        view3DAction.setStatusTip('View segmentation in 3D model')
+        view3DAction.triggered.connect(self.view3D)
+        fileMenu.addAction(view3DAction)
+
+        separator = fileMenu.addAction("")
+        separator.setSeparator(True)
+
         exitAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Exit', self)
         exitAction.setShortcut('Ctrl+Q')
         exitAction.setStatusTip('Exit application')
         exitAction.triggered.connect(QtGui.qApp.quit)
-
-        autoSeedsAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Automatic liver seeds', self)
-        # autoSeedsAction.setShortcut('Ctrl+Q')
-        autoSeedsAction.setStatusTip('Automatic liver seeds')
-        autoSeedsAction.triggered.connect(self.btnAutomaticLiverSeeds)
-
-        menubar = self.menuBar()
-        fileMenu = menubar.addMenu('&File')
         fileMenu.addAction(exitAction)
-        fileMenu.addAction(autoSeedsAction)
 
+
+        ###### IMAGE MENU ######
         imageMenu = menubar.addMenu('&Image')
 
         randomRotateAction= QtGui.QAction(QtGui.QIcon('exit.png'), '&Random Rotate', self)
@@ -109,6 +178,50 @@ class OrganSegmentationWindow(QMainWindow):
         randomRotateAction.triggered.connect(self.btnRandomRotate)
         imageMenu.addAction(randomRotateAction)
 
+        mirrorZAxisAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Mirror Z-axis', self)
+        mirrorZAxisAction.setStatusTip('Mirror Z-axis')
+        mirrorZAxisAction.triggered.connect(self.oseg.mirror_z_axis)
+        imageMenu.addAction(mirrorZAxisAction)
+
+
+        ###### OPTION MENU ######
+        optionMenu = menubar.addMenu('&Option')
+        
+        configAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Configuration', self)
+        configAction.setStatusTip('Config settings')
+        configAction.triggered.connect(self.btnConfig)
+        optionMenu.addAction(configAction)
+
+        logAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Log', self)
+        logAction.setStatusTip('See log file')
+        logAction.triggered.connect(self.btnLog)
+        optionMenu.addAction(logAction)
+
+        syncAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Sync', self)
+        syncAction.setStatusTip('Synchronize files from the server')
+        syncAction.triggered.connect(self.sync_lisa_data)
+        optionMenu.addAction(syncAction)        
+
+        updateAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&Update', self)
+        updateAction.setStatusTip('Check new update')
+        updateAction.triggered.connect(self.btnUpdate)
+        optionMenu.addAction(updateAction)
+
+
+        ###### CONFIG MENU ######
+        configMenu = menubar.addMenu('&Config')
+        # combo = QtGui.QComboBox(self)
+        for text in self.oseg.segmentation_alternative_params.keys():
+            iAction = QtGui.QAction(QtGui.QIcon('exit.png'), '&' + text, self)
+            iAction.setStatusTip('Use predefined config "%s"' % (text))
+            # something like lambda
+            fn = functools.partial(self.onAlternativeSegmentationParams, text)
+            iAction.triggered.connect(fn)
+
+            configMenu.addAction(iAction)
+        # combo.activated[str].connect(self.onAlternativeSegmentationParams)
+        # grid.addWidget(combo, 4, 1)
+
     def _add_button(
             self,
             text,
@@ -129,246 +242,178 @@ class OrganSegmentationWindow(QMainWindow):
 
         return btn
 
+    def _initUI_logo(self, grid):
+        lisa_logo = QLabel()
+        logopath = find_logo()
+        logo = QPixmap(logopath)
+        lisa_logo.setPixmap(logo)  # scaledToWidth(128))
+        grid.addWidget(lisa_logo, 0, 2, 2, 1)
+
+        rstart = 0
+        grid.addWidget(self.text_dcm_dir, rstart + 2, 1, 1, 4)
+        grid.addWidget(self.text_dcm_data, rstart + 3, 1, 1, 4)
+        grid.addWidget(self.text_seg_data, rstart + 4, 1, 1, 4)
+        return grid
+
+    def _activate_widget(self, widget):
+        self.currentWidget.hide()
+        self.grid.addWidget(widget,6,2)
+        widget.show()
+        self.currentWidget = widget
 
     def _initUI(self):
         cw = QWidget()
         self.setCentralWidget(cw)
         grid = QGridLayout()
         grid.setSpacing(10)
+
         self.uiw = {}
 
         # status bar
         self.statusBar().showMessage('Ready')
 
-        # menubar
-        self._initMenu()
+        ## menubar
+        #self._initMenu()
 
         font_label = QFont()
         font_label.setBold(True)
         font_info = QFont()
         font_info.setItalic(True)
         font_info.setPixelSize(10)
-
+        
         # # # # # # #
         # #  LISA logo
         # font_title = QFont()
         # font_title.setBold(True)
         # font_title.setSize(24)
 
-        lisa_title = QLabel('LIver Surgery Analyser')
-        info = QLabel('Developed by:\n' +
-                      'University of West Bohemia\n' +
-                      'Faculty of Applied Sciences\n' +
-                      QString.fromUtf8('M. Jiřík, V. Lukeš - 2013') +
-                      '\n\nVersion: ' + self.oseg.version
-                      )
-        info.setFont(font_info)
-        lisa_title.setFont(font_label)
-        lisa_logo = QLabel()
-        logopath = find_logo()
-        logo = QPixmap(logopath)
-        lisa_logo.setPixmap(logo)  # scaledToWidth(128))
-        grid.addWidget(lisa_title, 0, 1)
-        grid.addWidget(info, 1, 1)
-
-        btn_config = QPushButton("Configuration", self)
-        btn_config.clicked.connect(self.btnConfig)
-        self.uiw['config'] = btn_config
-        grid.addWidget(btn_config, 2, 1)
-
-        btn_update = QPushButton("Update", self)
-        btn_update.clicked.connect(self.btnUpdate)
-        self.uiw['btn_update'] = btn_update
-        grid.addWidget(btn_update, 3, 1)
-        grid.addWidget(lisa_logo, 0, 2, 5, 2)
-
-        combo = QtGui.QComboBox(self)
-        for text in self.oseg.segmentation_alternative_params.keys():
-            combo.addItem(text)
-        combo.activated[str].connect(self.onAlternativeSegmentationParams)
-        grid.addWidget(combo, 4, 1)
-
-
-        # right from logo
-        rstart = 0
-
-        btn_sync = QPushButton("Sync", self)
-        btn_sync.clicked.connect(self.sync_lisa_data)
-        self.uiw['sync'] = btn_sync
-        grid.addWidget(btn_sync, rstart + 3, 4)
-
-        grid.addWidget(
-            self._add_button("Log", self.btnLog, 'Log',
-                             "See log file", QStyle.SP_FileDialogContentsView),
-            rstart + 4, 4)
-
-        # # dicom reader
-        rstart = 5
-        hr = QFrame()
-        hr.setFrameShape(QFrame.HLine)
-        text_dcm = QLabel('DICOM reader')
-        text_dcm.setFont(font_label)
-
-        # btn_dcmdir = QPushButton("Load DICOM", self)
-        # btn_dcmdir.clicked.connect(self.loadDataDir)
-        # btn_dcmdir.setIcon(btn_dcmdir.style().standardIcon(QStyle.SP_DirOpenIcon))
-        # self.uiw['dcmdir'] = btn_dcmdir
-        # btn_datafile = QPushButton("Load file", self)
-        # btn_datafile.clicked.connect(self.loadDataFile)
-        # btn_datafile.setToolTip("Load data from pkl file, 3D Dicom, tiff, ...")
-
-        btn_dcmcrop = QPushButton("Crop", self)
-        btn_dcmcrop.clicked.connect(self.cropDcm)
-
-        # voxelsize gui comment
-        # elf.scaling_mode = 'original'
-        # ombo_vs = QComboBox(self)
-        # ombo_vs.activated[str].connect(self.changeVoxelSize)
-        # eys = scaling_modes.keys()
-        # eys.sort()
-        # ombo_vs.addItems(keys)
-        # ombo_vs.setCurrentIndex(keys.index(self.scaling_mode))
-        # elf.text_vs = QLabel('Voxel size:')
-        # end-- voxelsize gui
+        #lisa_title = QLabel('Liver Surgery Analyser')
+        #info = QLabel('Developed by:\n' +
+        #              'University of West Bohemia\n' +
+        #              'Faculty of Applied Sciences\n' +
+        #              QString.fromUtf8('M. Jiřík, V. Lukeš - 2013') +
+        #              '\n\nVersion: ' + self.oseg.version
+        #              )
+        #info.setFont(font_info)
+        #lisa_title.setFont(font_label)
+        #grid.addWidget(lisa_title, 0, 1)
+        #grid.addWidget(info, 1, 1)
         self.text_dcm_dir = QLabel('DICOM dir:')
         self.text_dcm_data = QLabel('DICOM data:')
-        grid.addWidget(hr, rstart + 0, 2, 1, 4)
-        grid.addWidget(text_dcm, rstart + 0, 1, 1, 3)
-        grid.addWidget(
-            self._add_button("Load dir", self.loadDataDir, 'dcmdir',
-                             "Load data from directory (DICOM, png, jpg...)", QStyle.SP_DirOpenIcon),
-            rstart + 1, 1)
-        grid.addWidget(
-            self._add_button("Load file", self.loadDataFile, 'load_file',
-                             "Load data from pkl file, 3D Dicom, tiff, ...", QStyle.SP_FileIcon),
-            rstart + 1, 2)
-        # grid.addWidget(btn_datafile, rstart + 1, 2)
-        grid.addWidget(btn_dcmcrop, rstart + 1, 3)
-        # voxelsize gui comment
-        # grid.addWidget(self.text_vs, rstart + 3, 1)
-        # grid.addWidget(combo_vs, rstart + 4, 1)
-        grid.addWidget(self.text_dcm_dir, rstart + 6, 1, 1, 4)
-        grid.addWidget(self.text_dcm_data, rstart + 7, 1, 1, 4)
-        rstart += 9
+        self.text_seg_data = QLabel('')
+        grid = self._initUI_logo(grid)
 
-        # # # # # # # # #  segmentation
-        hr = QFrame()
-        hr.setFrameShape(QFrame.HLine)
-        text_seg = QLabel('Segmentation')
-        text_seg.setFont(font_label)
 
-        btn_segfile = QPushButton("Seg. from file", self)
-        btn_segfile.clicked.connect(self.loadSegmentationFromFile)
-        btn_segfile.setToolTip("Load segmentation from pkl file, raw, ...")
+        ##### MAIN MENU #####
+        mainWidget = QWidget()
+        mainGrid = QGridLayout()
+        mainGrid.setSpacing(10)
 
-        btn_segcompare = QPushButton("Compare", self)
-        btn_segcompare.clicked.connect(self.compareSegmentationWithFile)
-        btn_segcompare.setToolTip(
-            "Compare data with segmentation from pkl file, raw, ...")
+        btnLoad = QPushButton("Load", self)
+        btnLoad.clicked.connect(self.btnLoad)
+        mainGrid.addWidget(btnLoad, 5, 2)
 
-        btn_mask = QPushButton("Mask region", self)
-        btn_mask.clicked.connect(self.maskRegion)
-        btn_segliver = QPushButton("Liver seg.", self)
-        btn_segliver.clicked.connect(self.liverSeg)
-        self.btn_segauto = QPushButton("Auto seg.", self)
-        self.btn_segauto.clicked.connect(self.autoSeg)
-        btn_segman = QPushButton("Manual seg.", self)
-        btn_segman.clicked.connect(self.manualSeg)
-        self.text_seg_data = QLabel('segmented data:')
-        grid.addWidget(hr, rstart + 0, 2, 1, 4)
-        grid.addWidget(text_seg, rstart + 0, 1)
-        grid.addWidget(btn_segfile, rstart + 1, 1)
-        grid.addWidget(btn_segcompare, rstart + 1, 3)
-        grid.addWidget(btn_mask, rstart + 2, 1)
-        grid.addWidget(btn_segliver, rstart + 2, 2)
-        grid.addWidget(self.btn_segauto, rstart + 1, 2)
-        grid.addWidget(btn_segman, rstart + 2, 3)
-        grid.addWidget(self.text_seg_data, rstart + 3, 1, 1, 3)
-        rstart += 4
+        btnSave = QPushButton("Save", self)
+        btnSave.clicked.connect(self.btnSave)
+        mainGrid.addWidget(btnSave, 6, 2)
 
-        # # # # # # # # #  save/view
-        # hr = QFrame()
-        # hr.setFrameShape(QFrame.HLine)
-        grid.addWidget(
-            self._add_button("Save", self.saveOut, 'save',
-                             "Save data with segmentation", QStyle.SP_DialogSaveButton),
-            rstart + 0, 1)
-        # btn_segsave = QPushButton("Save", self)
-        # btn_segsave.clicked.connect(self.saveOut)
-        btn_segsavedcmoverlay = QPushButton("Save Dicom Overlay", self)
-        btn_segsavedcmoverlay.clicked.connect(self.btnSaveOutDcmOverlay)
-        btn_segsavedcm = QPushButton("Save Dicom", self)
-        btn_segsavedcm.clicked.connect(self.btnSaveOutDcm)
-        btn_segview = QPushButton("View3D", self)
-        if viewer3D_available:
-            btn_segview.clicked.connect(self.view3D)
+        btnSegmentation = QPushButton("Segmentation", self)
+        btnSegmentation.clicked.connect(self.btnSegmentation)
+        mainGrid.addWidget(btnSegmentation, 7, 2)
 
-        else:
-            btn_segview.setEnabled(False)
+        btnCompare = QPushButton("Compare", self)
+        btnCompare.clicked.connect(self.compareSegmentationWithFile)
+        mainGrid.addWidget(btnCompare, 8, 2)
 
-        grid.addWidget(btn_segsavedcm, rstart + 0, 2)
-        grid.addWidget(btn_segsavedcmoverlay, rstart + 0, 3)
-        grid.addWidget(btn_segview, rstart + 0, 4)
-        rstart += 1
+        btnQuit = QPushButton("Quit", self)
+        btnQuit.clicked.connect(self.quit)
+        mainGrid.addWidget(btnQuit, 9, 2)
 
-        # # # # Virtual resection
 
-        hr = QFrame()
-        hr.setFrameShape(QFrame.HLine)
-        rstart += 1
 
-        hr = QFrame()
-        hr.setFrameShape(QFrame.HLine)
-        text_resection = QLabel('Virtual resection')
-        text_resection.setFont(font_label)
+        ##### LOAD MENU #####
+        loadWidget = QWidget()
+        loadGrid = QGridLayout()
+        loadGrid.setSpacing(10)
 
-        btn_pvseg = QPushButton("Portal vein seg.", self)
-        btn_pvseg.clicked.connect(self.btnPortalVeinSegmentation)
-        btn_svpv = QPushButton("Save PV tree", self)
-        btn_svpv.clicked.connect(self.btnSavePortalVeinTree)
-        btn_svpv.setToolTip("Save Portal Vein 1D model into vessel_tree.yaml")
-        # btn_svpv.setEnabled(False)
-        btn_svpv.setEnabled(True)
+        btnLoadFile = QPushButton("File", self)
+        btnLoadFile.clicked.connect(self.loadDataFile)
+        loadGrid.addWidget(btnLoadFile, 5, 2)
 
-        btn_hvseg = QPushButton("Hepatic veins seg.", self)
-        btn_hvseg.clicked.connect(self.btnHepaticVeinsSegmentation)
-        btn_svhv = QPushButton("Save HV tree", self)
-        btn_svhv.clicked.connect(self.btnSaveHepaticVeinsTree)
-        btn_svhv.setToolTip(
-            "Save Hepatic Veins 1D model into vessel_tree.yaml")
-        btn_svhv.setEnabled(True)
-        # btn_svhv.setEnabled(False)
+        btnLoadDir = QPushButton("Directory", self)
+        btnLoadDir.clicked.connect(self.loadDataDir)
+        loadGrid.addWidget(btnLoadDir, 6, 2)
 
-        btn_lesions = QPushButton("Lesions localization", self)
-        btn_lesions.clicked.connect(self.btnLesionLocalization)
-        # btn_lesions.setEnabled(False)
+        btnLoadSeg = QPushButton("Segmentation from file", self)
+        btnLoadSeg.clicked.connect(self.btnLoadSegmentationFromFile)
+        loadGrid.addWidget(btnLoadSeg, 7, 2)
 
-        btn_resection = QPushButton("Virtual resection", self)
-        btn_resection.clicked.connect(self.btnVirtualResection)
+        btnMainMenu = QPushButton("Back", self)
+        btnMainMenu.clicked.connect(self.btnMainMenu)
+        loadGrid.addWidget(btnMainMenu, 8, 2)
 
-        grid.addWidget(hr, rstart + 0, 2, 1, 4)
-        grid.addWidget(text_resection, rstart + 0, 1)
-        grid.addWidget(btn_pvseg, rstart + 1, 1)
-        grid.addWidget(btn_hvseg, rstart + 1, 2)
-        grid.addWidget(btn_lesions, rstart + 1, 3)
-        grid.addWidget(btn_resection, rstart + 2, 3)
-        grid.addWidget(btn_svpv, rstart + 2, 1)
-        grid.addWidget(btn_svhv, rstart + 2, 2)
 
-        # # # # # # #
+        ##### SAVE MENU #####
+        saveWidget = QWidget()
+        saveGrid = QGridLayout()
+        saveGrid.setSpacing(10)
 
-        hr = QFrame()
-        hr.setFrameShape(QFrame.HLine)
-        # rid.addWidget(hr, rstart + 0, 0, 1, 4)
+        btnSaveFile = QPushButton("File", self)
+        btnSaveFile.clicked.connect(self.saveOut)
+        saveGrid.addWidget(btnSaveFile, 5, 2)
 
-        rstart += 3
-        # quit
-        btn_quit = QPushButton("Quit", self)
-        btn_quit.clicked.connect(self.quit)
-        grid.addWidget(btn_quit, rstart + -1, 4, 1, 1)
-        self.uiw['quit'] = btn_quit
+        btnSaveDcm = QPushButton("Export Dicom", self)
+        btnSaveDcm.clicked.connect(self.btnSaveOutDcm)
+        saveGrid.addWidget(btnSaveDcm, 6, 2)
+
+        btnSaveDcmOverlay = QPushButton("Dicom overlay", self)
+        btnSaveDcmOverlay.clicked.connect(self.btnSaveOutDcmOverlay)
+        saveGrid.addWidget(btnSaveDcmOverlay, 6, 3)
+
+        btnSavePV = QPushButton("PV tree", self)
+        btnSavePV.clicked.connect(self.btnSavePortalVeinTree)
+        saveGrid.addWidget(btnSavePV, 7, 2)
+
+        btnSaveHV = QPushButton("HV tree", self)
+        btnSaveHV.clicked.connect(self.btnSaveHepaticVeinsTree)
+        saveGrid.addWidget(btnSaveHV, 8, 2)
+
+        btnMainMenu = QPushButton("Back", self)
+        btnMainMenu.clicked.connect(self.btnMainMenu)
+        saveGrid.addWidget(btnMainMenu, 9, 2)
+
+
+        ##### SEGMENTATION MENU #####
+        segWidget = QWidget()
+        segGrid = QGridLayout()
+        segGrid.setSpacing(10)
+
+        btnSegAuto = QPushButton("Semi-automatic", self)
+        btnSegAuto.clicked.connect(self.btnSemiautoSeg)
+        segGrid.addWidget(btnSegAuto, 4, 2)
+
+        btnSegManual = QPushButton("Manual", self)
+        btnSegManual.clicked.connect(self.btnManualSeg)
+        segGrid.addWidget(btnSegManual, 5, 2)
+
+        btnSegMask = QPushButton("Mask", self)
+        btnSegMask.clicked.connect(self.maskRegion)
+        segGrid.addWidget(btnSegMask, 6, 2)
+
+        btnSegPV = QPushButton("Portal Vein", self)
+        btnSegPV.clicked.connect(self.btnPortalVeinSegmentation)
+        segGrid.addWidget(btnSegPV, 7, 2)
+
+        btnSegHV = QPushButton("Hepatic Vein", self)
+        btnSegHV.clicked.connect(self.btnHepaticVeinsSegmentation)
+        segGrid.addWidget(btnSegHV, 8, 2)
+
+        btnMainMenu = QPushButton("Back", self)
+        btnMainMenu.clicked.connect(self.btnMainMenu)
+        segGrid.addWidget(btnMainMenu, 9, 2)
 
         if self.oseg.debug_mode:
+            rstart = 5
             btn_debug = QPushButton("Debug", self)
             btn_debug.clicked.connect(self.run_debug)
             grid.addWidget(btn_debug, rstart - 2, 4)
@@ -376,11 +421,59 @@ class OrganSegmentationWindow(QMainWindow):
         cw.setLayout(grid)
         self.cw = cw
         self.grid = grid
+        self.grid.addWidget(mainWidget,6,2)
+
+        mainWidget.setLayout(mainGrid)
+        self.mainWidget = mainWidget
+        self.mainGrid = mainGrid
+        self.currentWidget = mainWidget
+
+        loadWidget.setLayout(loadGrid)
+        self.loadWidget = loadWidget
+        self.loadGrid = loadGrid
+        self.loadWidget.hide()
+
+        saveWidget.setLayout(saveGrid)
+        self.saveWidget = saveWidget
+        self.saveGrid = saveGrid
+        self.saveWidget.hide()
+
+        segWidget.setLayout(segGrid)
+        self.segWidget = segWidget
+        self.segGrid = segGrid
+        self.segWidget.hide()
 
         self.setWindowTitle('LISA')
+        # self._initUI_logo(self.grid)
 
         self.show()
 
+
+    def btnLoad(self, event):
+        self._activate_widget(self.loadWidget)
+        # self.cw.hide()
+        # self.setCentralWidget(self.loadWidget)
+        # self._initUI_logo(self.loadGrid)
+        # self.loadWidget.show()
+
+    def btnSave(self, event):
+        self._activate_widget(self.saveWidget)
+        # self.cw.hide()
+        # self.setCentralWidget(self.saveWidget)
+        # self._initUI_logo(self.saveGrid)
+        # self.saveWidget.show()
+
+    def btnSegmentation(self, event):
+        self._activate_widget(self.segWidget)
+        # self.cw.hide()
+        # self.setCentralWidget(self.segWidget)
+        # self.segWidget.show()
+
+    def btnMainMenu(self, event):
+        self._activate_widget(self.mainWidget)
+        # self._initUI()
+        # self._initUI_logo(self.grid)
+
     def quit(self, event):
         return self.close()
 
@@ -636,7 +729,7 @@ class OrganSegmentationWindow(QMainWindow):
 
         self.statusBar().showMessage('Ready')
 
-    def loadSegmentationFromFile(self):
+    def btnLoadSegmentationFromFile(self):
         """
         Function make GUI for reading segmentaion file and calls
         organ_segmentation function to do the work.
@@ -724,7 +817,7 @@ class OrganSegmentationWindow(QMainWindow):
         # self.setLabelText(self.text_seg_data, text)
         self.statusBar().showMessage('Ready')
 
-    def liverSeg(self):
+    def btnSemiautoSeg(self):
         self.statusBar().showMessage('Performing liver segmentation ...')
         if self.oseg.data3d is None:
             self.statusBar().showMessage('No DICOM data!')
@@ -736,7 +829,7 @@ class OrganSegmentationWindow(QMainWindow):
         self.checkSegData('auto. seg., ')
         self.statusBar().showMessage('Ready')
 
-    def autoSeg(self):
+    def btnAutoSeg(self):
         self.statusBar().showMessage('Performing automatic segmentation...')
         QApplication.processEvents()
         if self.oseg.data3d is None:
@@ -746,7 +839,7 @@ class OrganSegmentationWindow(QMainWindow):
         self.oseg.run_sss()
         self.statusBar().showMessage('Automatic segmentation finished')
 
-    def manualSeg(self):
+    def btnManualSeg(self):
         oseg = self.oseg
         # rint 'ms d3d ', oseg.data3d.shape
         # rint 'ms seg ', oseg.segmentation.shape
@@ -821,13 +914,27 @@ class OrganSegmentationWindow(QMainWindow):
 
         self.statusBar().showMessage('Checking for update ...')
         self.oseg.update()
-        self.statusBar().showMessage('Update finished. Ready')
+        self.statusBar().showMessage('Update finished. Please restart Lisa')
 
     def btnAutomaticLiverSeeds(self, event=None):
         self.statusBar().showMessage('Automatic liver seeds...')
         self.oseg.automatic_liver_seeds()
         self.statusBar().showMessage('Ready')
 
+    def btnSaveSegmentation(self, event=None):
+        """
+        Not fully implemented yet
+        :param event:
+        :return:
+        """
+        import dictGUI
+        slab_selection = {}
+        for label, value in  self.oseg.slab.iteritems():
+            slab_selection[label] = True
+
+        slab_selection = dictGUI.dictGui(slab_selection)
+        # TODO use some function from oseg to store
+
     def btnConfig(self, event=None):
         import config
         import organ_segmentation as los
@@ -891,7 +998,13 @@ class OrganSegmentationWindow(QMainWindow):
         else:
             self.statusBar().showMessage('No segmentation data!')
 
-    def btnVirtualResection(self):
+    def btnVirtualResectionPV(self):
+        self._virtual_resection('PV')
+
+    def btnVirtualResectionPlanar(self):
+        self._virtual_resection('planar')
+
+    def _virtual_resection(self, method='planar'):
         # mport vessel_cut
 
         self.statusBar().showMessage('Performing virtual resection ...')
@@ -900,7 +1013,7 @@ class OrganSegmentationWindow(QMainWindow):
                 'slab': self.oseg.slab,
                 'voxelsize_mm': self.oseg.voxelsize_mm
                 }
-        cut = virtual_resection.resection(data, use_old_editor=True)
+        cut = virtual_resection.resection(data, method=method)
         self.oseg.segmentation = cut['segmentation']
         self.oseg.slab = cut['slab']
 
@@ -976,13 +1089,21 @@ class OrganSegmentationWindow(QMainWindow):
         # rom viewer import QVTKViewer
         oseg = self.oseg
         if oseg.segmentation is not None:
-            pts, els, et = gen_mesh_from_voxels(oseg.segmentation,
-                                                oseg.voxelsize_mm,
-                                                etype='q', mtype='s')
-            pts = smooth_mesh(pts, els, et,
-                              n_iter=10)
-            vtkdata = mesh2vtk(pts, els, et)
-            view = QVTKViewer(vtk_data=vtkdata)
+            import show_segmentation
+
+            show_segmentation.showSegmentation(
+                oseg.segmentation==1,
+                voxelsize_mm=oseg.voxelsize_mm,
+                degrad=1,
+                resize_mm=1.5
+            )
+            # pts, els, et = gen_mesh_from_voxels(oseg.segmentation,
+            #                                     oseg.voxelsize_mm,
+            #                                     etype='q', mtype='s')
+            # pts = smooth_mesh(pts, els, et,
+            #                   n_iter=10)
+            # vtkdata = mesh2vtk(pts, els, et)
+            # view = QVTKViewer(vtk_data=vtkdata)
             view.exec_()
 
         else:
