@@ -61,7 +61,7 @@ import data_plus
 import support_structure_segmentation as sss
 import cachefile as cachef
 import config_default
-import liver_seeds
+import organ_seeds
 import lisa_data
 
 # import audiosupport
@@ -194,7 +194,7 @@ class OrganSegmentation():
 
         self.iparams = {}
         self.datapath = datapath
-        self.output_datapath = output_datapath
+        self.set_output_datapath(output_datapath)
         self.sftp_username=sftp_username
         self.sftp_password=sftp_password
         self.input_datapath_start = input_datapath_start
@@ -227,9 +227,9 @@ class OrganSegmentation():
         self.processing_time = None
         self.experiment_caption = experiment_caption
         self.lisa_operator_identifier = lisa_operator_identifier
-        self.version = qmisc.getVersionString()
-        if self.version is None:
-            self.version = "1.8.7"
+        # self.version = qmisc.getVersionString()
+        # if self.version is None:
+        self.version = "1.9.2"
         self.viewermax = viewermax
         self.viewermin = viewermin
         self.volume_unit = volume_unit
@@ -323,9 +323,17 @@ class OrganSegmentation():
     #    self.orig_shape = datap['orig_shape']
     #    self.seeds = datap[
     #        'processing_information']['organ_segmentation']['seeds']
+
+    def set_output_datapath(self, output_datapath):
+        if output_datapath is None:
+            output_datapath = '~/lisa_data'
+        self.output_datapath = os.path.expanduser(output_datapath)
+
     def update(self):
-        import subprocess
-        print subprocess.call(['conda', 'update', '-y', '-c', 'mjirik', '-c', 'SimpleITK', 'lisa']) #, shell=True)
+        import update_stable
+        update_stable.make_update()
+        # import subprocess
+        # print subprocess.call(['conda', 'update', '-y', '-c', 'mjirik', '-c', 'SimpleITK', 'lisa']) #, shell=True)
 
     def update_parameters_based_on_label(self, label):
         self.update_parameters(self.segmentation_alternative_params[label])
@@ -355,6 +363,11 @@ class OrganSegmentation():
         if 'seg_postproc_pars' in params.keys():
             self.seg_postproc_pars = params['seg_postproc_pars']
             logger.debug('seg_postproc_pars updated')
+        if 'clean_seeds_after_update_parameters' in params.keys():
+
+            if self.seeds is not None:
+                self.seeds[...] = 0
+            logger.debug('clean_seeds_after_update_parameters')
 
 
     def run_sss(self):
@@ -671,8 +684,8 @@ class OrganSegmentation():
                      '\nmodelparams ' + str(self.segmodelparams)
                      )
         # insert feature function instead of string description
-        import liver_model
-        self.segmodelparams = liver_model.add_fv_extern_into_modelparams(self.segmodelparams)
+        import organ_model
+        self.segmodelparams = organ_model.add_fv_extern_into_modelparams(self.segmodelparams)
 
         if 'method' not in self.segparams.keys() or\
                 self.segparams['method'] in pycut.methods:
@@ -727,26 +740,34 @@ class OrganSegmentation():
             self.segmentation_prev = None
 
         return igc
-    def sync_lisa_data(self, username, password, host="147.228.47.162", callback=printTotals):
-        self.create_lisa_data_dir_tree()
 
+    def sync_lisa_data(self, username, password, host="147.228.47.162", callback=printTotals):
+        self.sftp_username = username
+        self.create_lisa_data_dir_tree()
 
         import sftpsync
         import paramiko
 
-        paramiko.util.log_to_file('paramiko.log')
+        paramiko_log = os.path.join(self.output_datapath, 'paramiko.log')
+        paramiko.util.log_to_file(paramiko_log)
         sftp = sftpsync.Sftp(host=host, username=username, password=password)
-        localfrom = self._output_datapath_from_server
-        localto = self._output_datapath_to_server
+        localfrom = self._output_datapath_from_server.replace(os.sep, '/')
+        localto = self._output_datapath_to_server.replace(os.sep, '/')
+        # this makes sure that all paths ends with slash
+        if not localfrom.endswith('/'):
+            localfrom += '/'
+        if not localto.endswith('/'):
+            localto += '/'
         remotefrom = "from_server/"
         remoteto = "to_server/"
 
         exclude = []
 
-        logger.info("Download started")
+        logger.info("Download started\nremote from {}\nlocal  from {}".format(remotefrom, localfrom))
+        logger.info("from")
         sftp.sync(remotefrom, localfrom, download=True, exclude=exclude, delete=False, callback=callback)
         logger.info("Download finished")
-        logger.info("Upload started")
+        logger.info("Upload started\nremote to {}\nlocal  to {}".format(remoteto, localto))
         sftp.sync(localto, remoteto, download=False, exclude=exclude, delete=False, callback=callback)
         logger.info("Upload finished")
 
@@ -893,7 +914,7 @@ class OrganSegmentation():
             # remove old pixels for this label
             self.segmentation_prev[self.segmentation_prev == self.output_label] = 0
             # set new labels
-            self.segmentation_prev[self.segmentation == 1] = self.output_label
+            self.segmentation_prev[np.where(self.segmentation == 1)] = self.output_label
 
             # clean up
 
@@ -1065,7 +1086,7 @@ class OrganSegmentation():
     #     return self.iparams
 
     def automatic_liver_seeds(self):
-        seeds, likdif = liver_seeds.automatic_liver_seeds(self.data3d, self.seeds, self.voxelsize_mm)
+        seeds, likdif = organ_seeds.automatic_liver_seeds(self.data3d, self.seeds, self.voxelsize_mm)
         # přenastavíme na čísla mezi nulou a jedničkou, druhá konstanta je nastavena empiricky
         self.apriori = boltzman(likdif, 0, 200).astype(np.float16)
 
@@ -1248,8 +1269,13 @@ class OrganSegmentation():
 
         output_dir = self.output_datapath
 
-        pth, filename = op.split(op.normpath(self.datapath))
-        filename += "-" + self.experiment_caption
+        if self.datapath is not None:
+            pth, filename = op.split(op.normpath(self.datapath))
+        else:
+            filename = ''
+        if len(filename) > 0 and len(self.experiment_caption) > 0:
+            filename += "-"
+        filename += self.experiment_caption
 #        if savestring in ['a', 'A']:
 # save renamed file too
         filename = '' + filename + suffix + '.' + filetype
@@ -1260,52 +1286,19 @@ class OrganSegmentation():
 
     def save_outputs(self, filepath=None):
 
-        # savestring_qt, ok = QInputDialog.getText(
-        #     None,
-        #     "Save",
-        #     'Save output data? Yes/No/All with input data (y/n/a):',
-        #     text="a"
-        #     )
-
-        # savestring = str(savestring_qt)
-
-        #    if savestring in ['Y', 'y', 'a', 'A']:
-
         data = self.export()
         data['version'] = self.version  # qmisc.getVersionString()
         data['experiment_caption'] = self.experiment_caption
         data['lisa_operator_identifier'] = self.lisa_operator_identifier
-#       data['organ_interactivity_counter'] = self.organ_interactivity_counter
-# save renamed file too
-#         pth, filename = op.split(op.normpath(self.datapath))
-#         filename += "-" + self.experiment_caption
-# #        if savestring in ['a', 'A']:
-#         filepath = 'org-' + filename + '.' + self.save_filetype
-#         # rint filepath
-#         # rint 'op ', op
         self.create_lisa_data_dir_tree()
 
         if filepath is None:
             filepath = self.get_standard_ouptut_filename()
         # import ipdb; ipdb.set_trace()
         import io3d
+        logger.debug("save outputs to file %s" % (filepath))
         io3d.write(data, filepath)
-        # from PyQt4 import QtCore; QtCore.pyqtRemoveInputHook()
-        # import ipdb; ipdb.set_trace()
-        # misc.obj_to_file(data, filepath, filetype=self.save_filetype)
 
-        # filepath2 = 'organ_last.' + self.save_filetype
-        # filepath2 = op.join(odp, filepath2)
-        # # ilepath = misc.suggest_filename(filepath)
-        # misc.obj_to_file(data, filepath2, filetype=self.save_filetype)
-# save to mat
-
-#        iparams = self.get_iparams()
-        # filepath = 'organ_iparams.pklz'
-        # filepath = op.join(odp, filepath)
-        # misc.obj_to_file(iparams, filepath, filetype='pklz')
-
-        # f savestring in ['a', 'A']:
     def create_lisa_data_dir_tree(self):
         lisa_data.create_lisa_data_dir_tree(self)
 
@@ -1320,11 +1313,35 @@ class OrganSegmentation():
         Rotate data3d, segmentation and seeds with random rotation
         :return:
         """
-        angle = np.random.rand() * 360
-        self.rotate(angle, (1, 2))
+        xi1 = np.random.rand()
+        xi2 = np.random.rand()
+
+        # theta = np.arccos(np.sqrt(1.0-xi1))
+        theta = np.arccos(1.0 - (xi1 * 1))
+        phi = xi2 * 2 * np.pi
+
+        # xs = np.sin(theta) * np.cos(phi)
+        # ys = np.sin(theta) * np.sin(phi)
+        # zs = np.cos(theta)
+
+        phi_deg = np.degrees(phi)
+        self.rotate(phi_deg, (1, 2))
+        theta_deg = np.degrees(theta)
+        self.rotate(theta_deg, (0, 1))
+        # TODO independent on voxlelsize (2016-techtest-rotate3d.ipynb)
+
+
+    def mirror_z_axis(self):
+        """
+        mirror data3d, segmentation and seeds Z-zaxis
+        :return:
+        """
+        self.data3d = self.data3d[-1::-1]
+        if self.segmentation is not None:
+            self.segmentation = self.segmentation[-1::-1]
+        if self.seeds is not None:
+            self.seeds = self.seeds[-1::-1]
 
-        angle = np.random.rand() * 360
-        self.rotate(angle, (0, 1))
 
     def save_input_dcm(self, filename):
         # TODO add
@@ -1550,6 +1567,18 @@ config and user config.")
         help='Smoothing of output segmentation',
         default=cfg["segmentation_smoothing"]
     )
+    parser.add_argument(
+        '-icn', '--make_icon',
+        action='store_true',
+        help='Create desktop icon on OS X and Linux',
+        default=False
+    )
+    parser.add_argument(
+        '-gsd', '--get_sample_data',
+        action='store_true',
+        help='Download sample data',
+        default=False
+    )
     parser.add_argument(
         '--save_filetype', type=str,  # type=int,
         help='File type of saving data. It can be pklz(default), pkl or mat',
@@ -1571,7 +1600,7 @@ def boltzman(x, xmid, tau):
     """
     return 1. / (1. + np.exp(-(x-xmid)/tau))
 
-def main():  # pragma: no cover
+def main(app=None, splash=None):  # pragma: no cover
 
     #    import ipdb; ipdb.set_trace() # BREAKPOINT
     try:
@@ -1579,6 +1608,15 @@ def main():  # pragma: no cover
         cfg = lisa_config_init()
         args = parser_init(cfg)
 
+        if cfg['make_icon'] is True:
+            import lisa_data
+            lisa_data.make_icon()
+            return
+        if cfg['get_sample_data'] is True:
+            import dataset
+            dataset.get_sample_data()
+            return
+
         # rint args["arg"]
         oseg_argspec_keys = config.get_function_keys(
             OrganSegmentation.__init__)
@@ -1602,13 +1640,20 @@ def main():  # pragma: no cover
         else:
             # mport_gui()
             from lisaWindow import OrganSegmentationWindow
+            import PyQt4
+            import PyQt4.QtGui
             from PyQt4.QtGui import QApplication
-            app = QApplication(sys.argv)
+            if app is None:
+                app = QApplication(sys.argv)
+            # Create and display the splash screen
             oseg_w = OrganSegmentationWindow(oseg)  # noqa
+            if splash is not None:
+                splash.finish(oseg_w)
 #    import pdb; pdb.set_trace()
             sys.exit(app.exec_())
 
     except Exception as e:
+        import traceback
         # mport exceptionProcessing
         exceptionProcessing.reportException(e)
         print traceback.format_exc()
