@@ -8,6 +8,7 @@ import traceback
 import logging
 logger = logging.getLogger(__name__)
 import datetime
+import os
 import os.path as op
 
 
@@ -50,18 +51,26 @@ def update_by_plan(filename="~/lisa_data/.update_plan.yaml", update_periode_days
 
 def update(dry_run=False):
     if update_by_plan():
-        # make_update(dry_run)
-        make_update_with_no_lisa_in_projects_dir(dry_run)
+        make_update(dry_run)
+        # make_update_with_no_lisa_in_projects_dir(dry_run)
 
 
-def make_update_with_no_lisa_in_projects_dir(dry_run=False):
+def make_update(dry_run=False):
+    """
+    Update with no projects/lisa directory
+    :param dry_run:
+    :return:
+    """
     import os.path as op
     conda_ok = True
     print ('Updating conda modules')
+    logger.debug("Updating conda modules")
     try:
         cmd = ["conda", "install", "--yes",
                # "-c", 'luispedro ',
-               '-c', 'SimpleITK', "-c", "menpo", '-c', 'mjirik', "lisa"
+               '-c', 'SimpleITK', "-c", "menpo", '-c', 'mjirik',
+               "-c", "menpo", "-c", "auto",
+               "lisa"
                ]
         if dry_run:
             cmd.append('--dry-run')
@@ -75,11 +84,16 @@ def make_update_with_no_lisa_in_projects_dir(dry_run=False):
         #     install_and_import('wget', '--user')
 
     print ('Updating pip modules')
+    logger.debug("Updating pip modules")
     try:
-        req_txt_path = op.expanduser("~/lisa_data")
+
+        req_txt_path = op.expanduser("~/lisa_data/.lisa/reqirements_pip.txt")
+        if op.exists(req_txt_path):
+            os.remove(req_txt_path)
+
         import wget
         wget.download(
-            "https://raw.githubusercontent.com/mjirik/lisa/master/lisa/requirements_pip.txt",
+            "https://raw.githubusercontent.com/mjirik/lisa/master/requirements_pip.txt",
             out=req_txt_path
         )
 
@@ -103,7 +117,7 @@ def make_update_with_no_lisa_in_projects_dir(dry_run=False):
         logger.warning(traceback.format_exc())
         traceback.print_exc()
 
-def make_update(dry_run=False):
+def make_update_old(dry_run=False):
     import os.path as op
     path_to_script = op.dirname(op.abspath(__file__))
     path_to_base = op.abspath(op.join(path_to_script, '../'))
